ArgsCount

Struct ArgsCount 

pub struct ArgsCount {
    pub input: IbuInput,
    pub output: Option<String>,
    pub mtx: bool,
    pub num_threads: usize,
    pub compressed: bool,
    pub features: Option<String>,
    pub feature_col: usize,
    pub suffix: Option<String>,
}

Fields

input: IbuInputoutput: Option<String>

Output file to write to [default=stdout]

mtx: bool

Output mtx format. Will treat output as a directory and create 3 files:

(1) barcodes.txt.gz (2) features.txt.gz (3) matrix.mtx.gz

num_threads: usize

Number of threads to use in counting

compressed: bool

Keep the barcode values 2bit compressed in the output

features: Option<String>

File containing the index features

If this is provided the index features names will be output instead of their index values

feature_col: usize

The column in the feature table to aggregate reads over - skips aggregation if this is zero

suffix: Option<String>

Suffix to append to cell barcodes

example: {barcode}-{suffix}

Implementations

Source

impl ArgsCount

pub fn from_wf_path<P: AsRef<Path>>( sort_path: &str, out_path: P, features_path: P, num_threads: usize, mtx: bool, suffix: Option<String>, ) -> Self