pub struct ArgsSort {
pub input: IbuInput,
pub output: Option<String>,
pub memory_limit: String,
pub in_memory: bool,
pub pipe: bool,
pub num_threads: usize,
}Fields
input: IbuInputoutput: Option<String>Output file to write to
Required unless -p/--pipe is present.
memory_limit: StringMemory limit for sorting in-memory
in_memory: boolPerform the sorting in-memory [default: on-disk merge sort]
This may be faster for small datasets, but will load IBUs fully into memory.
pipe: boolPipe the output to stdout
Due to binary output, this flag is necessary not to flood the terminal with binary.
num_threads: usizeImplementations