pub struct MultiPairedInput {
pub inputs: Vec<String>,
}Fields
inputs: Vec<String>Paths to input files to process.
If using BINSEQ input (.bq/.vbq), the ordering of files or number of files does not matter.
If using FASTX input, the input files are expected to be paired and sequentially ordered (S1_R1, S1_R2, S2_R1, S2_R2, …).
This is expecting an even number of files.
Implementations
Sourceimpl MultiPairedInput
impl MultiPairedInput
pub fn is_binseq(&self) -> bool
pub fn to_binseq_readers(&self) -> Result<Vec<BinseqReader>>
pub fn to_paraseq_collection(&self) -> Result<Collection<BoxedReader>>