pub struct ArgsGeomux {
pub geomux_min_umi_guides: usize,
pub geomux_log_odds_ratio: Option<f64>,
pub geomux_fdr_threshold: f64,
pub geomux_mode: GeomuxMode,
/* private fields */
}Fields
geomux_min_umi_guides: usizeMinimum number of UMIs required for a guide to be included in geomux testing.
geomux_log_odds_ratio: Option<f64>Log odds ratio minimum threshold to use for geomux assignments.
geomux_fdr_threshold: f64fdr threshold to use for geomux assignments.
geomux_mode: GeomuxModeMode to use for geomux testing.
Implementations
Sourceimpl ArgsGeomux
impl ArgsGeomux
pub fn min_umi_cells(&self) -> usize