pub struct ArgsCount {
pub input: IbuInput,
pub output: Option<String>,
pub mtx: bool,
pub num_threads: usize,
pub compressed: bool,
pub features: Option<String>,
pub feature_col: usize,
pub suffix: Option<String>,
}Fields
input: IbuInputoutput: Option<String>Output file to write to [default=stdout]
mtx: boolOutput mtx format.
Will treat output as a directory and create 3 files:
(1) barcodes.txt.gz (2) features.txt.gz (3) matrix.mtx.gz
num_threads: usizeNumber of threads to use in counting
compressed: boolKeep the barcode values 2bit compressed in the output
features: Option<String>File containing the index features
If this is provided the index features names will be output instead of their index values
feature_col: usizeThe column in the feature table to aggregate reads over - skips aggregation if this is zero
suffix: Option<String>Suffix to append to cell barcodes
example: {barcode}-{suffix}
Implementations